@@ -4,6 +4,7 @@ from copy import deepcopy
 from plone import api
 from plone.dexterity.utils import iterSchemata
 from zope.schema import getFields
+from plone.app.upgrade.utils import installOrReinstallProduct
 
 import logging
 import json
@@ -296,3 +297,26 @@ def to_1400(context):
     api.portal.set_registry_record(
         "plone.app.caching.terseCaching.plone.content.dynamic.ramCache", False
     )
+
+
+def to_2000(context):
+    portal_types = api.portal.get_tool(name="portal_types")
+    document_behaviors = list(portal_types["Document"].behaviors) + [
+        "volto.preview_image"
+    ]
+
+    old_images = api.portal.get_registry_record(name="plone.allowed_sizes")
+    installOrReinstallProduct(api.portal.get(), "plone.volto")
+
+    # adjust behaviors
+    portal_types["Document"].behaviors = tuple(document_behaviors)
+
+    # adjust image scales
+    new_images = api.portal.get_registry_record(name="plone.allowed_sizes")
+    new_keys = [x.split(" ")[0] for x in new_images]
+    for old_value in old_images:
+        miniature = old_value.split(" ")[0]
+        if miniature not in new_keys:
+            new_images.append(old_value)
+
+    api.portal.set_registry_record("plone.allowed_sizes", new_images)
